<?php

namespace Drupal\multi_peer_review;


/**
 * Defines a blank class used during development of the Multi Peer Review module.
 * Should be empty when used in production.
 * 
 */
class MPRBlank extends MPRSearchEngineScript {
    
  /**
   * {@inheritdoc}
   */
  function getName() { 
    return ("Australia Policy Online (APO) Scanner");       
  }
  
  /**
   * {@inheritdoc}
   */
  function getVersion() { 
    return ("1.0");
  }
  
  /**
   * {@inheritdoc}
   */
  function getDescription() { 
    return ("This script systematically browses the APO website’s “Browse” section to find papers on all subjects and then logs contributors mentioned in each paper’s page to return a list of potential reviewers."); 
  }
  
  /**
   * {@inheritdoc}
   */
  function getDeveloperName() { 
    return ("Home Modification Information Clearinghouse");
  }
  
  /**
   * {@inheritdoc}
   */
  function getDeveloperUrl() { 
    return ("https://www.homemods.info");       
  }


  /**
   * {@inheritdoc}
   */
  function buildSearchCache($target_new_result_count, $search_cancel_timestamp) {
    
              
    $target_url = "https://apo.org.au/page/browse";
    $data_source = "apo";    
    $new_result_count = 0;
    
    /* Load existing results to help avoid duplication. */
    $people = [];
    foreach ($this->getSearchResultItems() as $result_id => $result_item) {
        $people[$result_item->getRemoteId()] = unserialize($result_item->getRemoteData());
        $people[$result_item->getRemoteId()]["state"] = "cached";
    }
    
    
    $client = \Drupal::httpClient();    
    $resp = $this->getExternalUrl($client, $target_url);
    if ($resp["data"] != "") {
        $resp = $resp["data"];
        
        /* Find subjects on APO website. */
        $subjects = [];
        $subjects_source = $resp;
        $index = 0;
        foreach (explode("href=" . self::CHAR_DOUBLE_QUOTE . "/subject/", $subjects_source) as $subject_link_source) {
            if ($index != 0) {

                $subject = $this->getTextBetweenText($subject_link_source, ">", "</a>");
                $subject = trim(html_entity_decode($subject));

                $link = substr($subject_link_source, 0, strpos($subject_link_source, self::CHAR_DOUBLE_QUOTE));
                $link = "https://apo.org.au/subject/" . $link;

                $subjects[$subject] = $link;
            }

            $index++;
        }

        /* Scan each subject page and find people during the process. */   
        foreach ($subjects as $subject_name => $subject_url) {

            $page_index = 0;
            $max_pages = 100;
            while ($page_index < $max_pages) {
                $page_url = $subject_url . "?page=" . strval($page_index);

                $resp = $this->getExternalUrl($client, $page_url);
                if ($resp["data"] != "") {
                    $resp = $resp["data"];
                    
                    $publications_source = $resp;
                    if (strpos($publications_source, "rel=" . self::CHAR_DOUBLE_QUOTE . "next" . self::CHAR_DOUBLE_QUOTE) === FALSE) {
                        /* Stop processing this subject. */
                        $page_index = $max_pages;
                    }
                    
                    /* Cut down the source code to the area between the first view row and the pager. */
                    $publications_source = $this->getTextBetweenText($publications_source, "class=" . self::CHAR_DOUBLE_QUOTE . "views-row" . self::CHAR_DOUBLE_QUOTE, "pagination-heading");
                    
                    /* Split the source into results. */
                    $index = 0;
                    foreach (explode("node--view-mode-search-result", $publications_source) as $result_item_source) {
                        if ($index != 0) {
                        
                            /* Read result item information. */
                            $result_item_title = $this->getTextBetweenText($result_item_source, "<h2>", "</h2>");
                            $result_item_title = trim(html_entity_decode($this->getTextBetweenText($result_item_title, ">", "</a>")));
                            
                            $result_item_type = $this->getTextBetweenText($result_item_source, "label-box", "<h2>");
                            $result_item_type = str_replace(self::CHAR_LF, self::CHAR_EMPTY, $result_item_type);
                            $result_item_type = str_replace(self::CHAR_CR, self::CHAR_EMPTY, $result_item_type);
                            $result_item_type = trim(html_entity_decode($this->getTextBetweenText($result_item_type, ">", "</div>")));
                          
                            $result_item_link = $this->getTextBetweenText($result_item_source, "<h2>", "</h2>");
                            $result_item_link = "https://apo.org.au" . $this->getTextBetweenText($result_item_link, "href=" . self::CHAR_DOUBLE_QUOTE, self::CHAR_DOUBLE_QUOTE);
                            
                            $paper = [
                                "title" => $result_item_title,
                                "type" => $result_item_type,
                                "url" => $result_item_link,
                            ];
                            
                            
                            /* Find contributors. */
                            $first_person_record = TRUE;
                            foreach (explode("href=" . self::CHAR_DOUBLE_QUOTE . "/person/", $result_item_source) as $person_source) {
                                if ($first_person_record == FALSE) {
                                    
                                    /* Gather person’s details. */
                                    $person_url = substr($person_source, 0, strpos($person_source, self::CHAR_DOUBLE_QUOTE));
                                    $person_remote_id = $person_url;
                                    $person_url = "https://apo.org.au/person/" . $person_url;
                                    
                                    $person_name = trim(html_entity_decode($this->getTextBetweenText($person_source, ">", "</a>")));
                                                                        
                                    if (array_key_exists($person_remote_id, $people) == FALSE) {                                        
                                        /* Catalog new person. */
                                        
                                        $person_name_parts = explode(" ", $person_name, 2);
                                        if (count($person_name_parts) >= 2) {
                                            $person_first_name = $person_name_parts[0];
                                            $person_last_name = $person_name_parts[1];
                                        }
                                        else {
                                            $person_first_name = $person_name_parts[0];
                                            $person_last_name = "";                                            
                                        }
                                        
                                        $people[$person_remote_id] = [
                                            "remote_id" => $person_remote_id,
                                            "state" => "new",
                                            "url" => $person_url,
                                            "full_name" => $person_name,
                                            "first_name" => $person_first_name,
                                            "last_name" => $person_last_name,
                                            "subjects" => [$subject_name],
                                            "papers" => [$result_item_title => $paper],
                                        ];
                                        
                                        $new_result_count++;
                                    }     
                                    else {
                                        /* Update existing person. */
                                        if (in_array($subject_name, $people[$person_remote_id]["subjects"]) == FALSE) {
                                            array_push($people[$person_remote_id]["subjects"], $subject_name);
                                            
                                            if ($people[$person_remote_id]["state"] != "new") {
                                                $people[$person_remote_id]["state"] = "updated";
                                            }
                                        }
                                        
                                        if (array_key_exists($result_item_title, $people[$person_remote_id]["papers"]) == FALSE) {
                                            $people[$person_remote_id]["papers"][$result_item_title] = $paper;
                                            
                                            if ($people[$person_remote_id]["state"] != "new") {
                                                $people[$person_remote_id]["state"] = "updated";
                                            }                                            
                                        }                                                                           
                                    }
                                }
                                else {
                                    $first_person_record = FALSE;
                                }
                            }
                            
                        }
                        
                        $index++;                       
                    }
                    
                    
                }
                else {
                    /* Exit gracefully. */
                    $page_index = $max_pages;
                }

                $page_index++;    
                

                if (($new_result_count >= $target_new_result_count) || (time() >= $search_cancel_timestamp)) {
                    /* Exit gracefully. */
                    $page_index = $max_pages;
                }                
            }
            
            
            if (($new_result_count >= $target_new_result_count) || (time() >= $search_cancel_timestamp)) {
                break;
            }
        }
        
        /* Commit records to database. */
        foreach ($people as $remote_id => $person) {
            $search_result_item_id = $data_source . "_" . $person["remote_id"];
            
            
            switch ($person["state"]) {
                case "new":
                    $person["state"] = "cached";

                    $search_result_item = \Drupal\multi_peer_review\Entity\SearchResultItem::create([
                        "id" => $search_result_item_id,
                        "label" => $search_result_item_id . " " . $person["full_name"],
                        "full_name" => $person["full_name"],
                        "first_name" => $person["first_name"],
                        "last_name" => $person["last_name"],
                        "data_source" => $data_source,
                        "subjects" => implode(self::CHAR_LF, $person["subjects"]),
                        "external_papers" => serialize($person["papers"]),
                        "source_url" => $person["url"],
                        "remote_id" => $person["remote_id"],
                        "remote_data" => serialize($person),
                    ]);
                    $search_result_item->save();                        



                    break;
                case "updated":                                                
                    $person["state"] = "cached";

                    $search_result_item = \Drupal\multi_peer_review\Entity\SearchResultItem::load($search_result_item_id);
                    if (empty($search_result_item) == TRUE) {
                        /* Update the search result. */

                        $search_result_item->setSubjects(implode(self::CHAR_LF, $person["subjects"]));
                        $search_result_item->setExternalPapers(serialize($person["papers"]));
                        $search_result_item->setRemoteData(serialize($person));
                        $search_result_item->save(); 
                        
                    }

                    break;
            }            
                        

        }
    }
    
    
  }


  /**
   * {@inheritdoc}
   */
  function selfTest() { 
    $res = TRUE;
    
    $client = \Drupal::httpClient();    
    
    /* Test connectivity to main source page by bypassing the cache */
    $target_url = "https://apo.org.au/page/browse";            
    $resp = $this->getExternalUrl($client, $target_url, TRUE);
    if ($resp["data"] == "") {
        $res = FALSE;
    }
    else {
        $resp = $resp["data"];
        
        $required_strings = [
            "<title>Browse | APO</title>",
            "/subject/",
            "<h2>Subjects</h2>",
        ];
        
        foreach ($required_strings as $test_string) {
            if (strpos($resp, $test_string) === FALSE) {
                $res = FALSE;
                break;
            }
        }        
    }
    
    
    if ($res == TRUE) {


        /* Test connectivity to test subject page by bypassing the cache */
        $target_url = "https://apo.org.au/subject/57741";            
        $resp = $this->getExternalUrl($client, $target_url, TRUE);
        if ($resp["data"] == "") {
            $res = FALSE;
        }
        else {
            $resp = $resp["data"];

            $required_strings = [
                "node--view-mode-search-result",
                "label-box",
                "views-row",
                "<a href=" . self::CHAR_DOUBLE_QUOTE . "/node/",
            ];

            foreach ($required_strings as $test_string) {
                if (strpos($resp, $test_string) === FALSE) {
                    $res = FALSE;
                    break;
                }
            }        
        }

    }    
    
    
    return $res;
  }  
  
    
}
